.. _contributing:

====================================
Contributing to python-watcherclient
====================================

If you're interested in contributing to the python-watcherclient project,
the following will help get you started.


Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the python-watcherclient project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * https://docs.openstack.org/infra/manual/developers.html
   * https://wiki.openstack.org/CLA

LaunchPad Project
-----------------

Most of the tools used for OpenStack depend on a launchpad.net ID for
authentication. After signing up for a launchpad account, join the
"openstack" team to have access to the mailing list and receive
notifications of important events.

.. seealso::

   * http://launchpad.net
   * http://launchpad.net/python-watcherclient
   * http://launchpad.net/~openstack


Project Hosting Details
-------------------------

Bug tracker
    https://launchpad.net/python-watcherclient

Mailing list (prefix subjects with ``[watcher]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

Code Hosting
    https://opendev.org/openstack/python-watcherclient

Code Review
    https://review.opendev.org/#/q/status:open+project:openstack/python-watcherclient,n,z

